start

# Building

## UNIX

## Windows

### Requirements

- Innosetup
- py2exe

Consult the README in the source distribution for the build dependencies.

#### Building Python packages with C extensions under Windows

In order to build modules which have C extensions, you will need either the Visual Studio C++ compiler or MinGW.

Make sure that your Visual Studio C++ or MinGW program path is part of your system's program path, since the Python build system requires this.

To build and install a package with MinGW, you need to execute:

    ''python setup.py build -c mingw32 install''

from the command line.

To build a Windows installer when using MinGW, execute:

    ''python setup.py build -c mingw32 bdist_wininst''

### Building

Simply execute `python setup.py innosetup`.

The generated file can be found under `translate-toolkit-<version>\Output` (where `<version>` is the software version).